@@ -58,10 +58,12 @@ from flytekit.models.types import LiteralType, SimpleType, StructuredDatasetType
 T = typing.TypeVar("T")
 DEFINITIONS = "definitions"
 
+
 class NoneField(mm_fields.Constant):
     def __init__(self):
         super().__init__(None)
 
+
 class AnnotatedField(mm_fields.Field):
     def __init__(self, typ: Annotated, sub, *args, **kwargs):
         self.annotations = get_args(typ)[1:]
@@ -69,6 +71,7 @@ class AnnotatedField(mm_fields.Field):
 
         super().__init__(*args, **kwargs)
 
+
 class UnionField(mm_fields.Field):
     def __init__(self, typ, fields, *args, **kwargs):
         self.typ = typ
@@ -100,6 +103,7 @@ class UnionField(mm_fields.Field):
     #     # fuck this
     #     return super()._deserialize(value["value"], attr, data, **kwargs)
 
+
 import dataclasses_json.core as dcj_core
 import dataclasses_json.utils as dcj_utils
 
@@ -129,23 +133,24 @@ def build_type_hack(type_, options, mixin, field, cls):
 
         if dataclasses.is_dataclass(type_):
             if dcj_utils._issubclass_safe(type_, mixin):
-                options['field_many'] = bool(
-                    dcj_core._is_supported_generic(field.type) and dcj_utils._is_collection(
-                        field.type))
+                options["field_many"] = bool(
+                    dcj_core._is_supported_generic(field.type) and dcj_utils._is_collection(field.type)
+                )
                 return mm_fields.Nested(type_.schema(), **options)
             else:
-                warnings.warn(f"Nested dataclass field {field.name} of type "
-                              f"{field.type} detected in "
-                              f"{cls.__name__} that is not an instance of "
-                              f"dataclass_json. Did you mean to recursively "
-                              f"serialize this field? If so, make sure to "
-                              f"augment {type_} with either the "
-                              f"`dataclass_json` decorator or mixin.")
+                warnings.warn(
+                    f"Nested dataclass field {field.name} of type "
+                    f"{field.type} detected in "
+                    f"{cls.__name__} that is not an instance of "
+                    f"dataclass_json. Did you mean to recursively "
+                    f"serialize this field? If so, make sure to "
+                    f"augment {type_} with either the "
+                    f"`dataclass_json` decorator or mixin."
+                )
                 return mm_fields.Field(**options)
 
-        origin = getattr(type_, '__origin__', type_)
-        args = [inner(a, {}) for a in getattr(type_, '__args__', []) if
-                a is not type(None)]
+        origin = getattr(type_, "__origin__", type_)
+        args = [inner(a, {}) for a in getattr(type_, "__args__", []) if a is not type(None)]
 
         if dcj_utils._is_optional(type_):
             options["allow_none"] = True
@@ -158,13 +163,16 @@ def build_type_hack(type_, options, mixin, field, cls):
 
         warnings.warn(
             f"Unknown type {type_} at {cls.__name__}.{field.name}: {field.type} "
-            f"It's advised to pass the correct marshmallow type to `mm_field`.")
+            f"It's advised to pass the correct marshmallow type to `mm_field`."
+        )
         return mm_fields.Field(**options)
 
     return inner(type_, options)
 
+
 dataclasses_json_mm.build_type = build_type_hack
 
+
 class TypeTransformerFailedError(TypeError, AssertionError, ValueError):
     ...
 
@@ -400,9 +408,10 @@ class DataclassTransformer(TypeTransformer[object]):
         schema = None
         try:
             s = cast(DataClassJsonMixin, t).schema()
+
             class FlyteJSONSchema(JSONSchema):
                 def get_required(self, obj):
-                    return [field.data_key or field.name for field in obj.fields.values()]
+                    return sorted([field.data_key or field.name for field in obj.fields.values()])
 
                 def _get_schema_for_field(self, obj, field):
                     if isinstance(field, EnumField):
@@ -411,11 +420,10 @@ class DataclassTransformer(TypeTransformer[object]):
                         field.load_by = LoadDumpOptions.name
 
                     if isinstance(field, NoneField):
-                        return {
-                            "type": "null"
-                        }
+                        return {"type": "null"}
 
                     if isinstance(field, UnionField):
+
                         def get_type(t):
                             tr = TypeEngine.get_transformer(t)
                             typ = tr.get_literal_type(t)
@@ -428,13 +436,12 @@ class DataclassTransformer(TypeTransformer[object]):
                                     "type": "object",
                                     "properties": {
                                         "value": self._get_schema_for_field(obj, f),
-                                        "type": {
-                                            "const": get_type(t)
-                                        }
+                                        "type": {"const": get_type(t)},
                                     },
                                     "required": ["value", "type"],
-                                    "additionalProperties": False
-                                } for f, t in zip(field.fields, get_args(field.typ))
+                                    "additionalProperties": False,
+                                }
+                                for f, t in zip(field.fields, get_args(field.typ))
                             ]
                         }
 
@@ -476,18 +483,17 @@ class DataclassTransformer(TypeTransformer[object]):
                 f"Dataclass {python_type} should be decorated with @dataclass_json to be " f"serialized correctly"
             )
         if not isinstance(python_val, python_type):
-            raise TypeTransformerFailedError(f"Cannot convert value of type {type(python_val)} to dataclass {python_type}")
+            raise TypeTransformerFailedError(
+                f"Cannot convert value of type {type(python_val)} to dataclass {python_type}"
+            )
 
         schema = expected.metadata
-        ref = schema["$ref"][len("#/definitions/"):]
+        ref = schema["$ref"][len("#/definitions/") :]
         defs = schema["definitions"]
 
         self._dataclass_superhack(python_val, python_type, defs[ref], defs)
         res = cast(DataClassJsonMixin, python_val).to_json()
-        return Literal(
-            scalar=Scalar(generic=_json_format.Parse(res, _struct.Struct()))
-        )
-
+        return Literal(scalar=Scalar(generic=_json_format.Parse(res, _struct.Struct())))
 
     def _flyte_type_superhack(self, v: T, field_type: Type[T], schema, defs):
         from flytekit.types.directory.types import FlyteDirectory
@@ -514,13 +520,22 @@ class DataclassTransformer(TypeTransformer[object]):
                 return field_type(path=lv.scalar.blob.uri)
             elif issubclass(field_type, StructuredDataset):
                 return field_type(
-                        uri=lv.scalar.structured_dataset.uri,
-                    )
+                    uri=lv.scalar.structured_dataset.uri,
+                )
         elif dataclasses.is_dataclass(field_type):
-            self._dataclass_superhack(v, field_type, defs[schema["$ref"][len("#/definitions/"):]], defs)
+            self._dataclass_superhack(v, field_type, defs[schema["$ref"][len("#/definitions/") :]], defs)
         elif get_origin(field_type) is typing.Union:
             schema = schema["oneOf"]
-            expected = LiteralType(union_type=UnionType(variants=[LiteralType.from_flyte_idl(_ParseDict(x["properties"]["type"]["const"], _types_pb2.LiteralType())) for x in schema]))
+            expected = LiteralType(
+                union_type=UnionType(
+                    variants=[
+                        LiteralType.from_flyte_idl(
+                            _ParseDict(x["properties"]["type"]["const"], _types_pb2.LiteralType())
+                        )
+                        for x in schema
+                    ]
+                )
+            )
 
             tr = cast(UnionTransformer, TypeEngine.get_transformer(field_type))
             lit, pytype, idx = tr._to_literal_ext(FlyteContext.current_context(), v, field_type, expected)
@@ -530,7 +545,7 @@ class DataclassTransformer(TypeTransformer[object]):
 
             return {
                 "value": self._flyte_type_superhack(v, pytype, schema[idx]["properties"]["value"], defs),
-                "type": _MessageToDict(lit.scalar.union.stored_type.to_flyte_idl())
+                "type": _MessageToDict(lit.scalar.union.stored_type.to_flyte_idl()),
             }
         elif get_origin(field_type) is list:
             value_type = get_args(field_type)[0]
@@ -538,7 +553,6 @@ class DataclassTransformer(TypeTransformer[object]):
 
         return v
 
-
     def _dataclass_superhack(self, python_val: T, python_type: Type[T], schema, defs):
         for f in dataclasses.fields(python_type):
             v = getattr(python_val, f.name)
@@ -552,7 +566,9 @@ class DataclassTransformer(TypeTransformer[object]):
         from flytekit.types.structured.structured_dataset import StructuredDataset, StructuredDatasetTransformerEngine
 
         if dataclasses.is_dataclass(expected_python_type) and isinstance(python_val, dict):
-            return self._dataclass_deserialize_superhack(expected_python_type.from_dict(python_val), expected_python_type)
+            return self._dataclass_deserialize_superhack(
+                expected_python_type.from_dict(python_val), expected_python_type
+            )
 
         if get_origin(expected_python_type) is typing.Union:
             stored_type = LiteralType.from_flyte_idl(_ParseDict(python_val["type"], _types_pb2.LiteralType()))
@@ -569,7 +585,9 @@ class DataclassTransformer(TypeTransformer[object]):
                 t = FlyteSchemaTransformer()
                 return t.to_python_value(
                     FlyteContext.current_context(),
-                    Literal(scalar=Scalar(schema=Schema(python_val.remote_path, t._get_schema_type(expected_python_type)))),
+                    Literal(
+                        scalar=Scalar(schema=Schema(python_val.remote_path, t._get_schema_type(expected_python_type)))
+                    ),
                     expected_python_type,
                 )
             elif issubclass(expected_python_type, FlyteFile):
@@ -690,7 +708,9 @@ class DataclassTransformer(TypeTransformer[object]):
             raise TypeTransformerFailedError(f"Did not match JSON schema for dataclass {expected_python_type}") from e
 
         dc = cast(DataClassJsonMixin, expected_python_type).from_dict(data)
-        return self._fix_dataclass_int(expected_python_type, self._dataclass_deserialize_superhack(dc, expected_python_type))
+        return self._fix_dataclass_int(
+            expected_python_type, self._dataclass_deserialize_superhack(dc, expected_python_type)
+        )
 
     # This ensures that calls with the same literal type returns the same dataclass. For example, `pyflyte run``
     # command needs to call guess_python_type to get the TypeEngine-derived dataclass. Without caching here, separate
@@ -1086,6 +1106,14 @@ def _add_tag_to_type(x: LiteralType, tag: str) -> LiteralType:
 
 
 def _type_essence(x: LiteralType) -> LiteralType:
+    if x.simple == SimpleType.STRUCT:
+        if x.structure is not None or x.annotation is not None:
+            x = LiteralType.from_flyte_idl(x.to_flyte_idl())
+            x._structure = None
+            x._annotation = None
+
+        return x
+
     if x.metadata is not None or x.structure is not None or x.annotation is not None:
         x = LiteralType.from_flyte_idl(x.to_flyte_idl())
         x._metadata = None
@@ -1186,7 +1214,9 @@ class UnionTransformer(TypeTransformer[T]):
         except Exception as e:
             raise ValueError(f"Type of Generic Union type is not supported, {e}")
 
-    def _to_literal_ext(self, ctx: FlyteContext, python_val: T, python_type: Type[T], expected: LiteralType) -> Tuple[Literal, Any, int]:
+    def _to_literal_ext(
+        self, ctx: FlyteContext, python_val: T, python_type: Type[T], expected: LiteralType
+    ) -> Tuple[Literal, Any, int]:
         if get_origin(python_type) is Annotated:
             python_type = get_args(python_type)[0]
 
