@@ -245,8 +245,7 @@ class FlyteFilePathTransformer(TypeTransformer[FlyteFile]):
         if isinstance(v, os.PathLike) or isinstance(v, FlyteFile) or isinstance(v, str):
             return
         raise TypeError(
-            f"No automatic conversion found from type {type(v)} to FlyteFile."
-            f"Supported (os.PathLike, str, Flytefile)"
+            f"No automatic conversion found from type {type(v)} to FlyteFile.Supported (os.PathLike, str, Flytefile)"
         )
 
     def get_literal_type(self, t: typing.Union[typing.Type[FlyteFile], os.PathLike]) -> LiteralType:
@@ -265,9 +264,6 @@ class FlyteFilePathTransformer(TypeTransformer[FlyteFile]):
         if python_val is None:
             raise TypeTransformerFailedError("None value cannot be converted to a file.")
 
-        if not (python_type is os.PathLike or issubclass(python_type, FlyteFile)):
-            raise ValueError(f"Incorrect type {python_type}, must be either a FlyteFile or os.PathLike")
-
         # information used by all cases
         meta = BlobMetadata(type=self._blob_type(format=FlyteFilePathTransformer.get_format(python_type)))
 
@@ -288,7 +284,7 @@ class FlyteFilePathTransformer(TypeTransformer[FlyteFile]):
             if python_type is os.PathLike:
                 logger.warning(
                     f"Converting from a FlyteFile Python instance to a Blob Flyte object, but only a {python_type} was"
-                    f" specified. Since a simpler type was specified, we'll skip uploading!"
+                    " specified. Since a simpler type was specified, we'll skip uploading!"
                 )
                 should_upload = False
 
@@ -309,7 +305,9 @@ class FlyteFilePathTransformer(TypeTransformer[FlyteFile]):
                         p = pathlib.Path(python_val)
                         try:
                             if not p.is_file():
-                                raise TypeTransformerFailedError(f"Error converting {python_val} because it's not a file.")
+                                raise TypeTransformerFailedError(
+                                    f"Error converting {python_val} because it's not a file."
+                                )
                         except:
                             raise TypeTransformerFailedError(f"Error converting {python_val} because it's not a file.")
 
